


#include <i2c.h>

#include "h/FonctionsI2C.h"
#include "h/Parametres.h"



/* Ecriture d'un octet grce au module  I2C  du PIC18F4550

Paramtres d'entre :

Adresse - Adresse d'criture, sur le bus  I2C , du composant que l'on souhaite crire,
Donnees - Donne  crire.

Valeur de retour :

0x01 si l'criture s'est effectue correctement, 0x00 s'il y a eu une erreur lors de l'criture.

*/
unsigned char Ecrire(unsigned char Adresse, unsigned char Donnee) 
{
	unsigned char Information = 0x00;
	
	IdleI2C();    /* Attente de la disponibilit du bus I2C. */
	StartI2C();    /* Envoi de message de dbut de la communication I2C. */
	IdleI2C();    /* Attente de la disponibilit du bus I2C. */
	
	putcI2C(Adresse); /* Envoi de l'adresse de l'esclave. */
	IdleI2C();   /* Attente de la disponibilit du bus I2C. */
	
	if(SSPCON2bits.ACKSTAT) /*Si AckStat == 1, on n'a pas reu d'acquittement de la part de l'esclave. */
	{
		StopI2C();  /* Envoi du message de fin de la communication I2C. */

		return Information;   /* On renvoie  0x00  , ce qui indique qu'il y a eu un problme lors de l'criture. */
	}
	
	putcI2C(Donnee);   /* On envoie la valeur  crire  l'esclave. */
	IdleI2C();   /* Attente de la disponibilit du bus I2C. */
	
	if(!(SSPCON2bits.ACKSTAT)) /* Si on reoit un acquitement de la part de l'esclave,
							   on retournera  0x01   la fin de la fontion d'criture. */
	{
		Information = 0x01;
	}
	
	StopI2C();    /* Envoi de message de fin de la communication I2C. */
	
	return Information;
}



/* Lecture d'un octet grce au module  I2C  du PIC18F4550

Paramtres d'entre :

Adresse - Adresse de lecture, sur le bus  I2C , du composant que l'on souhaite lire.

Valeur de retour :

Valeur lue si l'criture s'est effectue correctement, 0x00 s'il y a eu une erreur lors de la lecture.

*/
unsigned char Lire(unsigned char Adresse)
{
unsigned char Valeur = 0x00;

	IdleI2C();    /* Attente de la disponibilit du bus I2C. */
	StartI2C();    /* Envoi de message de dbut de la communication I2C. */
	IdleI2C();    /* Attente de la disponibilit du bus I2C. */
	
	putcI2C(Adresse); /* Envoi de l'Adresse de l'esclave. */
	IdleI2C();   /* Attente de la disponibilit du bus I2C. */
	
	if (SSPCON2bits.ACKSTAT) /* Si AckStat == 1, on n'a pas reu d'acquittement de la part de l'esclave. */
	{
		StopI2C();  /* Envoi de message de fin de la communication I2C. */
		
		return Valeur;   /* On renvoie 0x00, ce qui indique qu'il y a eu un problme. */
	}
	
	Valeur = ReadI2C(); /* Lecture de la valeur qui est reue sur le bus I2C. */
	
	NotAckI2C();   /* On n'envoie pas d'acquittement car on ne lit qu'un seul caractre. */
	
	IdleI2C();   /* Attente de la disponibilit du bus I2C. */
	
	StopI2C();   /* Envoi de message de fin de la communication I2C. */
	
	return Valeur;   /* On renvoie la valeur lue. */
}


