


#include <p18f4550.h>
#include <i2c.h>

#include "h/FonctionsI2C.h"
#include "h/LCD.h"
#include "h/Caracteres.h"
#include "h/Platine.h"
#include "h/Utilitaires.h"
#include "h/Parametres.h"


/* Bits de configuration du microcontrleur PIC18F4550, indpendants du programme,
voir  Help -> Topics -> PicC18 config settings . */

#pragma config BOR = ON
#pragma config MCLRE = OFF
#pragma config LVP = OFF	/* Low Voltage Programming dsactiv => RB5 I/O normale. */
#pragma config PBADEN = OFF	/* PORTB<4> and PORTB<1:0> Configured as Digital I/O Pins on Reset. */
#pragma config DEBUG = OFF	/* Dbug dsactiv => RB6 et RB7 normal I/O. */
#pragma config FCMEN = OFF	/* Fail-Safe Clock dsactive. */
#pragma config IESO = OFF	/* Oscillator Switchover mode dsactiv. */
#pragma config PWRT = OFF
#pragma config WDT = OFF	/* Watchdog dsactiv. */
#pragma config WDTPS = 1024	/* Prdiviseur du Watchdog. */
#pragma config LPT1OSC = OFF
#pragma config XINST = OFF	/* Instruction set extension and Indexed Addressing mode disabled (Legacy mode). */
#pragma config STVREN = OFF	/* Pas de reset du  la pile. */ 
#pragma config FOSC = INTOSCIO_EC



extern const rom char g_Speciaux_Generiques[64];
extern const rom char g_Speciaux_Accentues[64];
extern const rom char g_Speciaux_Progression[64];



void InitialisationMicrocontroleur(void);


void InitialisationMicrocontroleur(void)
{
	/* Configuration de l'horloge interne du PIC18F4550. */
	OSCCON = 0x70;
	OSCTUNE = 0x40;
	
	/* Dsactivation du module CCP. */
	CCP1CON=0;
	
	/* Dsactivation du convertisseur analogique numerique. */
	ADCON1=0x0F;

	PIE1bits.SSPIE = 0;
	PIR1bits.SSPIF = 0;
}

/* Fonction principale 

Paramtre d'entre :

Aucun.

Valeur de retour :

Aucune.

*/
void main(void)
{
	unsigned char k;
	unsigned char Phase;

	InitialisationMicrocontroleur();

	TRISBbits.TRISB0 = 1;	/* Configuration de la broche  SDA  , utilise par le bus I2C,
							en tant qu'entre logique. */
	TRISBbits.TRISB1 = 1;	/* Configuration de la broche  SCL  , utilise par le bus I2C,
							en tant qu'entre logique. */
	/* 	SDA : RB0,
		SCL : RB1. */

	OpenI2C(MASTER, SLEW_OFF);

	SSPADD = 99;
	SSPCON1bits.CKP = 0;

	ChangerEtatRetroeclairage(1);
	
	InitialisationAfficheur();
	
	ChargeCaracteres(g_Speciaux_Generiques);	/* Chargement des huit caractres spciaux,
									dfinis dans le tableau  g_Speciaux  , points par points,
									dans la  CG RAM  de l'afficheur LCD alphanumrique. */
	
	EnvoiCommande(0x01);	/* Effacement de l'afficheur LCD. */
	Delai(1000);
	PlacerCurseur(0x00);	/* Placement du curseur  la premire position
							o l'on peut afficher des caractres, sur l'afficheur LCD alphanumrique. */	

	AfficheCaractere(0x04);	/* Affichage du caractre spcial d'adresse  0x02  - Symbole  Flche vers la gauche . */

	AfficheTexte(" CANCOILLOTTE\0");	

	PlacerCurseur(0x40);

	AfficheTexte("SAINT-NECTAIRE \0");

	AfficheCaractere(0x05);	/* Affichage du caractre spcial d'adresse  0x03  - Symbole  Flche vers la droite . */

	Delai(3000);

	ChargeCaracteres(g_Speciaux_Progression);

	EnvoiCommande(0x01);	/* Effacement de l'afficheur LCD. */
	Delai(1000);
	PlacerCurseur(0x00);	/* Placement du curseur  la premire position
							o l'on peut afficher des caractres, sur l'afficheur LCD alphanumrique. */

	AfficheTexte("Progression :\0");

	for(k = 0; k < 16; k++)
	{
		PlacerCurseur(0x40 + k);
		AfficheCaractere(' ');
		Delai(1000);
		PlacerCurseur(0x40 + k);
		AfficheCaractere(0x00);	/* Affichage du caractre spcial d'adresse  0x00 . */
		Delai(1000);
		PlacerCurseur(0x40 + k);
		AfficheCaractere(0x01);	/* Affichage du caractre spcial d'adresse  0x01 . */
		Delai(1000);
		PlacerCurseur(0x40 + k);
		AfficheCaractere(0x02);	/* Affichage du caractre spcial d'adresse  0x02 . */
		Delai(1000);
		PlacerCurseur(0x40 + k);
		AfficheCaractere(0xFF);
		Delai(1000);
	}

	while(1);
}


